@@ -7,16 +7,7 @@
 #include <thread>
 #include <boost/iterator/counting_iterator.hpp>
 
-#pragma GCC diagnostic push
-#if __GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6)
-#pragma GCC diagnostic ignored "-Wpragmas"
-#endif
-#pragma GCC diagnostic ignored "-Wunknown-pragmas"
-#pragma GCC diagnostic ignored "-Wignored-attributes" // To keep C++14 quiet
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 #include "RcppParallel.h"
-#pragma GCC diagnostic pop
-
 //#include "engine/ThreadPool.h"
 
 namespace bsccs {
